package com.ruoyi.system.service.impl;

import java.time.LocalDate;
import java.util.List;

import com.ruoyi.system.domain.dto.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.DailySysMapper;
import com.ruoyi.system.domain.DailySys;
import com.ruoyi.system.service.IDailySysService;

/**
 * 记录系统每天需要统计的任务Service业务层处理
 * 
 * @author haoitan
 * @date 2024-11-07
 */
@Service
public class DailySysServiceImpl implements IDailySysService 
{
    @Autowired
    private DailySysMapper dailySysMapper;

    /**
     * 查询记录系统每天需要统计的任务
     * 
     * @param dailySysId 记录系统每天需要统计的任务主键
     * @return 记录系统每天需要统计的任务
     */
    @Override
    public DailySys selectDailySysByDailySysId(Long dailySysId)
    {
        return dailySysMapper.selectDailySysByDailySysId(dailySysId);
    }


    //根据日期返回 系统数据
    @Override
    public DailySys selectDailySysByDate(LocalDate date)
    {
        return dailySysMapper.selectDailySysByDate(date);
    }

    /**
     * 查询记录系统每天需要统计的任务列表
     * 
     * @param dailySys 记录系统每天需要统计的任务
     * @return 记录系统每天需要统计的任务
     */
    @Override
    public List<DailySys> selectDailySysList(DailySys dailySys)
    {
        return dailySysMapper.selectDailySysList(dailySys);
    }

    @Override
    public List<SeUserCountDto> getSeUserCount(LocalDate startDate, LocalDate endDate){

        return dailySysMapper.selectDailySysListBetweenDate(startDate, endDate);

    }

    @Override
    public List<SeUserWorkCountDto> getSeUserWorkCount(LocalDate startDate, LocalDate endDate){
        return dailySysMapper.selectDailySysWorkListBetweenDate(startDate, endDate);
    }

    public List<SeOnlineTimeDto> gettOnlineTime(LocalDate startDate, LocalDate endDate){
        return dailySysMapper.gettOnlineTime(startDate, endDate);
    }

    @Override
    public List<SysIncomeDto> getSysIncome(LocalDate startDate, LocalDate endDate){
        return dailySysMapper.getSysIncome(startDate, endDate);
    }

    @Override
    public List<SourceUseCountDto> getSourceUserCount(LocalDate startDate, LocalDate endDate){
        return dailySysMapper.getSourceUserCount(startDate, endDate);
    }

    /**
     * 新增记录系统每天需要统计的任务
     * 
     * @param dailySys 记录系统每天需要统计的任务
     * @return 结果
     */
    @Override
    public int insertDailySys(DailySys dailySys)
    {
        return dailySysMapper.insertDailySys(dailySys);
    }

    /**
     * 修改记录系统每天需要统计的任务
     * 
     * @param dailySys 记录系统每天需要统计的任务
     * @return 结果
     */
    @Override
    public int updateDailySys(DailySys dailySys)
    {
        return dailySysMapper.updateDailySys(dailySys);
    }

    /**
     * 批量删除记录系统每天需要统计的任务
     * 
     * @param dailySysIds 需要删除的记录系统每天需要统计的任务主键
     * @return 结果
     */
    @Override
    public int deleteDailySysByDailySysIds(Long[] dailySysIds)
    {
        return dailySysMapper.deleteDailySysByDailySysIds(dailySysIds);
    }

    /**
     * 删除记录系统每天需要统计的任务信息
     * 
     * @param dailySysId 记录系统每天需要统计的任务主键
     * @return 结果
     */
    @Override
    public int deleteDailySysByDailySysId(Long dailySysId)
    {
        return dailySysMapper.deleteDailySysByDailySysId(dailySysId);
    }

//    @Override
//    public Long getUserCount()
//    {
//    	return dailySysMapper.getUserCount();
//    }

}
